@@ -30,7 +30,7 @@
 
 #include "gdaemonfile.h"
 #include "gvfsdaemondbus.h"
-#include "gdaemonvolume.h"
+#include "gdaemonmount.h"
 #include <gvfsdaemonprotocol.h>
 #include <gdaemonfileinputstream.h>
 #include <gdaemonfileoutputstream.h>
@@ -40,7 +40,7 @@
 #include <glib/gi18n-lib.h>
 #include "gdbusutils.h"
 #include "gmountoperationdbus.h"
-#include <gio/gsimpleasyncresult.h>
+#include <gio/gio.h>
 
 static void g_daemon_file_file_iface_init (GFileIface       *iface);
 
@@ -492,7 +492,7 @@ do_sync_2_path_call (GFile *file1,
       /* For copy this will cause the fallback code to be involved */
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
 		   _("Operation not supported, files on different mounts"));
-      return FALSE;
+      return NULL;
     }
   
   message =
@@ -1176,7 +1176,7 @@ mount_mountable_location_mounted_cb (GObject *source_object,
   GSimpleAsyncResult *result = user_data;
   GError *error = NULL;
   
-  if (!g_mount_for_location_finish (G_FILE (source_object), res, &error))
+  if (!g_file_mount_enclosing_volume_finish (G_FILE (source_object), res, &error))
     {
       g_simple_async_result_set_from_error (result, error);
       g_error_free (error);
@@ -1226,11 +1226,11 @@ mount_mountable_async_cb (DBusMessage *reply,
 
       if (must_mount_location)
 	{
-	  g_mount_for_location (file,
-				mount_operation,
-				cancellable,
-				mount_mountable_location_mounted_cb,
-				g_object_ref (result));
+	  g_file_mount_enclosing_volume (file,
+					 mount_operation,
+					 cancellable,
+					 mount_mountable_location_mounted_cb,
+					 g_object_ref (result));
 	  
 	}
       else
@@ -1291,11 +1291,11 @@ typedef struct {
   gpointer user_data;
 } MountData;
 
-static void g_daemon_file_mount_for_location (GFile *location,
-					      GMountOperation *mount_operation,
-					      GCancellable *cancellable,
-					      GAsyncReadyCallback callback,
-					      gpointer user_data);
+static void g_daemon_file_mount_enclosing_volume (GFile *location,
+						  GMountOperation *mount_operation,
+						  GCancellable *cancellable,
+						  GAsyncReadyCallback callback,
+						  gpointer user_data);
 
 static void
 mount_reply (DBusMessage *reply,
@@ -1317,7 +1317,7 @@ mount_reply (DBusMessage *reply,
       res = g_simple_async_result_new (G_OBJECT (data->file),
 				       data->callback,
 				       data->user_data,
-				       g_daemon_file_mount_for_location);
+				       g_daemon_file_mount_enclosing_volume);
     }
 
   g_simple_async_result_complete (res);
@@ -1329,11 +1329,11 @@ mount_reply (DBusMessage *reply,
 }
 
 static void
-g_daemon_file_mount_for_location (GFile *location,
-				  GMountOperation *mount_operation,
-				  GCancellable *cancellable,
-				  GAsyncReadyCallback callback,
-				  gpointer user_data)
+g_daemon_file_mount_enclosing_volume (GFile *location,
+				      GMountOperation *mount_operation,
+				      GCancellable *cancellable,
+				      GAsyncReadyCallback callback,
+				      gpointer user_data)
 {
   GDaemonFile *daemon_file;
   DBusMessage *message;
@@ -1376,9 +1376,9 @@ g_daemon_file_mount_for_location (GFile *location,
 }
 
 static gboolean
-g_daemon_file_mount_for_location_finish (GFile                  *location,
-					 GAsyncResult           *result,
-					 GError                **error)
+g_daemon_file_mount_enclosing_volume_finish (GFile                  *location,
+					     GAsyncResult           *result,
+					     GError                **error)
 {
   /* Errors handled in generic code */
   return TRUE;
@@ -1422,14 +1422,14 @@ g_daemon_file_query_filesystem_info (GFile                *file,
   return info;
 }
 
-static GVolume *
-g_daemon_file_find_enclosing_volume (GFile *file,
-				     GCancellable *cancellable,
-				     GError **error)
+static GMount *
+g_daemon_file_find_enclosing_mount (GFile *file,
+                                    GCancellable *cancellable,
+                                    GError **error)
 {
   GDaemonFile *daemon_file = G_DAEMON_FILE (file);
   GMountInfo *mount_info;
-  GDaemonVolume *volume;
+  GDaemonMount *mount;
   
   mount_info = _g_daemon_vfs_get_mount_info_sync (daemon_file->mount_spec,
 						  daemon_file->path,
@@ -1439,16 +1439,16 @@ g_daemon_file_find_enclosing_volume (GFile *file,
 
   if (mount_info->user_visible)
     {
-      volume = g_daemon_volume_new (mount_info);
+      mount = g_daemon_mount_new (mount_info, NULL);
       g_mount_info_unref (mount_info);
       
-      if (volume)
-	return G_VOLUME (volume);
+      if (mount)
+	return G_MOUNT (mount);
     }
 
   g_set_error (error, G_IO_ERROR,
 	       G_IO_ERROR_NOT_FOUND,
-	       _("Containing volume does not exist"));
+	       _("Containing mount does not exist"));
   return NULL;
 }
 
@@ -1673,7 +1673,8 @@ g_daemon_file_query_writable_namespaces (GFile                      *file,
 static gboolean
 g_daemon_file_set_attribute (GFile *file,
 			     const char *attribute,
-			     const GFileAttributeValue *value,
+			     GFileAttributeType    type,
+			     gpointer              value_p,
 			     GFileQueryInfoFlags flags,
 			     GCancellable *cancellable,
 			     GError **error)
@@ -1696,7 +1697,7 @@ g_daemon_file_set_attribute (GFile *file,
 				  DBUS_TYPE_UINT32,
 				  &flags_dbus);
 
-  _g_dbus_append_file_attribute (&iter, attribute, value);
+  _g_dbus_append_file_attribute (&iter, attribute, type, value_p);
 
   reply = _g_vfs_daemon_call_sync (message,
 				   NULL,
@@ -1958,15 +1959,15 @@ g_daemon_file_file_iface_init (GFileIface *iface)
   iface->query_info = g_daemon_file_query_info;
   iface->query_info_async = g_daemon_file_query_info_async;
   iface->query_info_finish = g_daemon_file_query_info_finish;
-  iface->find_enclosing_volume = g_daemon_file_find_enclosing_volume;
-  iface->read = g_daemon_file_read;
+  iface->find_enclosing_mount = g_daemon_file_find_enclosing_mount;
+  iface->read_fn = g_daemon_file_read;
   iface->append_to = g_daemon_file_append_to;
   iface->create = g_daemon_file_create;
   iface->replace = g_daemon_file_replace;
   iface->read_async = g_daemon_file_read_async;
   iface->read_finish = g_daemon_file_read_finish;
-  iface->mount_for_location = g_daemon_file_mount_for_location;
-  iface->mount_for_location_finish = g_daemon_file_mount_for_location_finish;
+  iface->mount_enclosing_volume = g_daemon_file_mount_enclosing_volume;
+  iface->mount_enclosing_volume_finish = g_daemon_file_mount_enclosing_volume_finish;
   iface->mount_mountable = g_daemon_file_mount_mountable;
   iface->mount_mountable_finish = g_daemon_file_mount_mountable_finish;
   iface->query_filesystem_info = g_daemon_file_query_filesystem_info;
