@@ -24,8 +24,7 @@
 #define __G_VFS_BACKEND_H__
 
 #include <dbus/dbus.h>
-#include <gio/gfileinfo.h>
-#include <gio/gfile.h>
+#include <gio/gio.h>
 #include <gvfsdaemon.h>
 #include <gvfsjob.h>
 #include <gmountspec.h>
@@ -298,13 +297,15 @@ struct _GVfsBackendClass
 				 GVfsJobSetAttribute *set_attribute,
 				 const char *filename,
 				 const char *attribute,
-				 GFileAttributeValue *value,
+				 GFileAttributeType type,
+				 gpointer value_p,
 				 GFileQueryInfoFlags flags);
   gboolean (*try_set_attribute) (GVfsBackend *backend,
 				 GVfsJobSetAttribute *set_attribute,
 				 const char *filename,
 				 const char *attribute,
-				 GFileAttributeValue *value,
+				 GFileAttributeType type,
+				 gpointer value_p,
 				 GFileQueryInfoFlags flags);
   void     (*create_dir_monitor)(GVfsBackend *backend,
 				 GVfsJobCreateMonitor *job,
@@ -344,6 +345,8 @@ GType g_vfs_lookup_backend         (const char         *type);
 
 void        g_vfs_backend_set_display_name               (GVfsBackend        *backend,
 							  const char         *display_name);
+void        g_vfs_backend_set_stable_name                (GVfsBackend        *backend,
+							  const char         *stable_name);
 void        g_vfs_backend_set_icon_name                  (GVfsBackend        *backend,
 							  const char         *icon);
 void        g_vfs_backend_set_prefered_filename_encoding (GVfsBackend        *backend,
@@ -360,6 +363,7 @@ void        g_vfs_backend_unregister_mount               (GVfsBackend        *ba
 							  gpointer            user_data);
 const char *g_vfs_backend_get_backend_type               (GVfsBackend        *backend);
 const char *g_vfs_backend_get_display_name               (GVfsBackend        *backend);
+const char *g_vfs_backend_get_stable_name                  (GVfsBackend        *backend);
 const char *g_vfs_backend_get_icon_name                  (GVfsBackend        *backend);
 GMountSpec *g_vfs_backend_get_mount_spec                 (GVfsBackend        *backend);
 GVfsDaemon *g_vfs_backend_get_daemon                     (GVfsBackend        *backend);
