@@ -34,11 +34,9 @@
 
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
-#include <gio/gioerror.h>
-#include <gio/gfile.h>
-#include <gio/gthemedicon.h>
+#include <gio/gio.h>
 #include <gio/gunixmounts.h>
-#include <gio/gurifuncs.h>
+#include <glib/gurifuncs.h>
 
 #include "gvfsbackendtrash.h"
 #include "gvfsmonitor.h"
@@ -329,7 +327,7 @@ decode_path (const char *filename, char **trashdir, char **trashfile, char **rel
 typedef enum {
   HAS_SYSTEM_DIR = 1<<0,
   HAS_USER_DIR = 1<<1,
-  HAS_TRASH_FILES = 1<<1,
+  HAS_TRASH_FILES = 1<<1
 } TopdirInfo;
 
 static TopdirInfo
@@ -510,7 +508,7 @@ list_trash_dirs (void)
   GList *mounts, *l, *li;
   const char *topdir;
   char *home_trash;
-  GUnixMount *mount;
+  GUnixMountEntry *mount;
   GList *dirs;
   GList *topdirs;
   GList *topdirs_info;
@@ -532,7 +530,7 @@ list_trash_dirs (void)
     g_free (home_trash);
 
   topdirs = NULL;
-  mounts = g_get_unix_mounts (NULL);
+  mounts = g_unix_mounts_get (NULL);
   for (l = mounts; l != NULL; l = l->next)
     {
       mount = l->data;
@@ -1003,7 +1001,7 @@ enumerate_root_trashdir (GVfsBackend *backend,
   files_file = g_file_get_child (file, "files");
   enumerator =
     g_file_enumerate_children (files_file,
-                               job ? job->attributes : G_FILE_ATTRIBUTE_STD_NAME,
+                               job ? job->attributes : G_FILE_ATTRIBUTE_STANDARD_NAME,
                                job ? job->flags : 0,
                                job ? G_VFS_JOB (job)->cancellable : NULL,
                                NULL);
@@ -1175,7 +1173,7 @@ do_query_info (GVfsBackend *backend,
       g_object_unref (icon);
       
       g_file_info_set_attribute_boolean (info,
-                                         G_FILE_ATTRIBUTE_STD_IS_VIRTUAL,
+                                         G_FILE_ATTRIBUTE_STANDARD_IS_VIRTUAL,
                                          TRUE);
       g_file_info_set_attribute_boolean (info,
                                          G_FILE_ATTRIBUTE_ACCESS_CAN_READ,
